@@ -69,7 +69,7 @@ GVDirPart::GVDirPart(TQWidget* parentWidget, const char* /*widgetName*/, TQObjec
 	mBrowserExtension = new GVDirPartBrowserExtension(this);
 
 	mSplitter = new TQSplitter(Qt::Horizontal, parentWidget, "gwenview-kpart-splitter");
-	mSplitter->setFocusPolicy(TQ_ClickFocus);
+	mSplitter->setFocusPolicy(TQWidget::ClickFocus);
 	mSplitter->setOpaqueResize(true);
 
 	// Create the widgets
