@@ -58,7 +58,7 @@ class TSCurrentThread;
 class TSThread
     : public TQObject
     {
-    Q_OBJECT
+    TQ_OBJECT
   
     public:
         TSThread();
